@@ -33,6 +33,7 @@ type ExtensionParams struct {
 	AppName      string
 	Organization *fly.Organization
 	Provider     string
+	PlanID       string
 	Options      map[string]interface{}
 }
 
@@ -114,6 +115,10 @@ func ProvisionExtension(ctx context.Context, params ExtensionParams) (extension
 		Type:           gql.AddOnType(provider.Name),
 	}
 
+	if params.PlanID != "" {
+		input.PlanId = params.PlanID
+	}
+
 	var inExcludedRegion bool
 	var primaryRegion string
 
