@@ -6,10 +6,10 @@ import (
 
 	"github.com/spf13/cobra"
 
+	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/gql"
 	"github.com/superfly/flyctl/iostreams"
 
-	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/prompt"
@@ -17,7 +17,7 @@ import (
 
 func newUpdate() (cmd *cobra.Command) {
 	const (
-		long = `Update an Upstash Redis database`
+		long = `Update an Upstash Redis database settings, payment plan or replica regions`
 
 		short = long
 		usage = "update <name>"
@@ -37,7 +37,7 @@ func newUpdate() (cmd *cobra.Command) {
 func runUpdate(ctx context.Context) (err error) {
 	var (
 		out    = iostreams.FromContext(ctx).Out
-		client = client.FromContext(ctx).API().GenqClient
+		client = fly.ClientFromContext(ctx).GenqClient
 	)
 
 	id := flag.FirstArg(ctx)
@@ -50,7 +50,6 @@ func runUpdate(ctx context.Context) (err error) {
 	addOn := response.AddOn
 
 	excludedRegions, err := GetExcludedRegions(ctx)
-
 	if err != nil {
 		return err
 	}
@@ -61,66 +60,39 @@ func runUpdate(ctx context.Context) (err error) {
 		return
 	}
 
-	var index int
-	var promptOptions []string
-
-	result, err := gql.ListAddOnPlans(ctx, client)
-	if err != nil {
-		return
-	}
-
-	for _, plan := range result.AddOnPlans.Nodes {
-		promptOptions = append(promptOptions, fmt.Sprintf("%s: %s Max Data Size, $%d/month/region", plan.DisplayName, plan.MaxDataSize, plan.PricePerMonth))
-	}
-
-	err = prompt.Select(ctx, &index, "Select an Upstash Redis plan", "", promptOptions...)
-
-	if err != nil {
-		return fmt.Errorf("failed to select a plan: %w", err)
-	}
-
-	// type Options struct {
-	// 	Eviction bool
-	// }
-
-	// options := &Options{}
-
 	options, _ := addOn.Options.(map[string]interface{})
 
+	plan := addOn.AddOnPlan.Id
+
+	if addOn.AddOnPlan.Id == redisPlanFree {
+		if upgradePlan, err := prompt.Confirm(ctx, "Would you like to upgrade to the unrestricted Pay-as-you-go plan?"); upgradePlan || err != nil {
+			plan = redisPlanPayAsYouGo
+		}
+	}
+
 	if err != nil {
 		return
 	}
 
 	if options["eviction"] != nil && options["eviction"].(bool) {
-		if disableEviction, err := prompt.Confirm(ctx, " Would you like to disable eviction?"); disableEviction || err != nil {
+		if disableEviction, err := prompt.Confirm(ctx, "Would you like to disable eviction?"); disableEviction || err != nil {
 			options["eviction"] = false
 		}
-
 	} else {
-		options["eviction"], err = prompt.Confirm(ctx, " Would you like to enable eviction?")
+		options["eviction"], err = prompt.Confirm(ctx, "Would you like to enable eviction?")
 	}
 
 	if err != nil {
 		return
 	}
 
-	_ = `# @genqlient
-  mutation UpdateAddOn($addOnId: ID!, $planId: ID!, $readRegions: [String!]!, $options: JSON!) {
-		updateAddOn(input: {addOnId: $addOnId, planId: $planId, readRegions: $readRegions, options: $options}) {
-			addOn {
-				id
-			}
-		}
-  }
-	`
-
 	readRegionCodes := []string{}
 
 	for _, region := range *readRegions {
 		readRegionCodes = append(readRegionCodes, region.Code)
 	}
 
-	_, err = gql.UpdateAddOn(ctx, client, addOn.Id, result.AddOnPlans.Nodes[index].Id, readRegionCodes, options)
+	_, err = gql.UpdateAddOn(ctx, client, addOn.Id, plan, readRegionCodes, options)
 
 	if err != nil {
 		return
